@@ -1,13 +1,18 @@
 """Provide a model for the Z-Wave JS Driver."""
-from typing import TYPE_CHECKING, Any, Dict, Literal, Optional, Type, Union, cast
+from __future__ import annotations
 
-from pydantic import create_model_from_typeddict
+from typing import TYPE_CHECKING, Any, Literal, cast
 
 from ..event import BaseEventModel, Event, EventBase
 from .controller import Controller
 from .log_config import LogConfig, LogConfigDataType
 from .log_message import LogMessage, LogMessageDataType
 
+try:
+    from pydantic.v1 import create_model_from_typeddict
+except ImportError:
+    from pydantic import create_model_from_typeddict
+
 if TYPE_CHECKING:
     from ..client import Client
 
@@ -36,7 +41,7 @@ LoggingEventModel = create_model_from_typeddict(
 )
 
 
-DRIVER_EVENT_MODEL_MAP: Dict[str, Type["BaseDriverEventModel"]] = {
+DRIVER_EVENT_MODEL_MAP: dict[str, type["BaseDriverEventModel"]] = {
     "all nodes ready": AllNodesReadyEventModel,
     "log config updated": LogConfigUpdatedEventModel,
     "logging": LoggingEventModel,
@@ -50,7 +55,7 @@ class CheckConfigUpdates:
         """Initialize class."""
         self.installed_version: str = data["installedVersion"]
         self.update_available: bool = data["updateAvailable"]
-        self.new_version: Optional[str] = data.get("newVersion")
+        self.new_version: str | None = data.get("newVersion")
 
 
 class Driver(EventBase):
@@ -88,7 +93,7 @@ class Driver(EventBase):
         self.emit(event.type, event.data)
 
     async def _async_send_command(
-        self, command: str, require_schema: int = None, **kwargs: Any
+        self, command: str, require_schema: int | None = None, **kwargs: Any
     ) -> dict:
         """Send a driver command. For internal use only."""
         return await self.client.async_send_command(
@@ -155,7 +160,7 @@ class Driver(EventBase):
         return cast(bool, result["success"])
 
     async def async_set_preferred_scales(
-        self, scales: Dict[Union[str, int], Union[str, int]]
+        self, scales: dict[str | int, str | int]
     ) -> None:
         """Send command to set preferred sensor scales."""
         await self._async_send_command(
@@ -166,6 +171,23 @@ class Driver(EventBase):
         """Send command to enable Sentry error reporting."""
         await self._async_send_command("enable_error_reporting", require_schema=16)
 
+    async def async_hard_reset(self) -> None:
+        """Send command to hard reset controller."""
+        await self._async_send_command("hard_reset", require_schema=25)
+
+    async def async_try_soft_reset(self) -> None:
+        """Send command to try to soft reset controller."""
+        await self._async_send_command("try_soft_reset", require_schema=25)
+
+    async def async_soft_reset(self) -> None:
+        """Send command to soft reset controller."""
+        await self._async_send_command("soft_reset", require_schema=25)
+
+    async def async_shutdown(self) -> bool:
+        """Send command to shutdown controller."""
+        data = await self._async_send_command("shutdown", require_schema=27)
+        return cast(bool, data["success"])
+
     def handle_logging(self, event: Event) -> None:
         """Process a driver logging event."""
         event.data["log_message"] = LogMessage(cast(LogMessageDataType, event.data))
